@@ -6,6 +6,7 @@ use strict;
 use warnings;
 
 use base 'Mojo::Server::Daemon';
+use bytes;
 
 use Carp 'croak';
 use Fcntl ':flock';
@@ -49,36 +50,7 @@ use constant CHUNK_SIZE => $ENV{MOJO_CHUNK_SIZE} || 4096;
 # Lisa, tell your mother to get off my case.
 # Uhhh, dad, Lisa's the one you're not talking to.
 # Bart, go to your room.
-sub accept_lock {
-    my ($self, $blocking) = @_;
-
-    # Idle
-    if ($blocking) {
-        $self->_child_write->syswrite("$$ idle\n")
-          or croak "Can't write to parent: $!";
-    }
-
-    # Lock
-    my $lock =
-      $blocking
-      ? flock($self->_lock, LOCK_EX)
-      : flock($self->_lock, LOCK_EX | LOCK_NB);
-
-    # Busy
-    if ($lock) {
-        $self->_child_write->syswrite("$$ busy\n")
-          or croak "Can't write to parent: $!";
-    }
-
-    return $lock;
-}
-
-sub accept_unlock { flock(shift->_lock, LOCK_UN) }
-
-sub child {
-    my $self = shift;
-    do { $self->spin } while keys %{$self->_connections};
-}
+sub child { shift->ioloop->start }
 
 sub daemonize {
     my $self = shift;
@@ -101,7 +73,42 @@ sub daemonize {
     return $$;
 }
 
-sub parent { shift->listen }
+sub parent {
+    my $self = shift;
+
+    # Lock callback
+    $self->ioloop->lock_cb(
+        sub {
+            my ($loop, $blocking) = @_;
+
+            # Idle
+            if ($blocking) {
+                $self->_child_write->syswrite("$$ idle\n")
+                  or croak "Can't write to parent: $!";
+            }
+
+            # Lock
+            my $lock =
+              $blocking
+              ? flock($self->_lock, LOCK_EX)
+              : flock($self->_lock, LOCK_EX | LOCK_NB);
+
+            # Busy
+            if ($lock) {
+                $self->_child_write->syswrite("$$ busy\n")
+                  or croak "Can't write to parent: $!";
+            }
+
+            return $lock;
+        }
+    );
+
+    # Unlock callback
+    $self->ioloop->unlock_cb(sub { flock($self->_lock, LOCK_UN) });
+
+    # Prepare IOLoop
+    $self->prepare_ioloop;
+}
 
 sub run {
     my $self = shift;
@@ -320,7 +327,8 @@ sub _spawn_child {
 
     # Child signal handlers
     else {
-        $SIG{HUP} = $SIG{INT} = $SIG{CHLD} = $SIG{TERM} = sub { exit 0 }
+        $SIG{HUP} = $SIG{INT} = $SIG{TERM} = sub { exit 0 };
+        $SIG{CHLD} = 'DEFAULT';
     }
 
     # Do child stuff
@@ -429,15 +437,6 @@ L<Mojo::Server::Daemon> and implements the following new ones.
 L<Mojo::Server::Daemon::Prefork> inherits all methods from
 L<Mojo::Server::Daemon> and implements the following new ones.
 
-=head2 C<accept_lock>
-
-    my $locked = $daemon->accept_lock;
-    my $locked = $daemon->accept_lock(1);
-
-=head2 C<accept_unlock>
-
-    $daemon->accept_unlock;
-
 =head2 C<child>
 
     $daemon->child;
